<?php

namespace Teknisa\CADFIS\Controllers;

use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Row;
use Zeedhi\Framework\DataSource\DataSet;

class Ger00250ParametrizacaoInscricaoEstadualController extends \Teknisa\CADFIS\Controllers\TeknisaCrud {

    protected $crudService;
    protected $dataSourceName = '';
    protected $dataSourceNameToSave = '';
    protected $parameterBagColumns  = array();

    protected $ger00250ParametrizacaoInscricaoEstadualService;

    public function __construct($crudService, $parameterBag, $ger00250ParametrizacaoInscricaoEstadualService) {
        parent::__construct($crudService, $parameterBag);
        $this->crudService = $crudService;
        $this->ger00250ParametrizacaoInscricaoEstadualService = $ger00250ParametrizacaoInscricaoEstadualService;
    }

    public function findCodajusteefdicmsInscricao(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName='codajusteefdicms_inscrestad';
        $this->parameterBagColumns = array("P_CDEMPRESA","P_CDINSCESTA");
        parent::find($request,$response);
    }

    public function findInscrestadst(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName='inscrestadst_completa';
        $this->parameterBagColumns = array("P_CDEMPRESA","P_CDINSCESTA");
        parent::find($request,$response);
    }

    public function findCredprescfop(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName='credprescfop_telaInscricao';
        $this->parameterBagColumns = array("P_CDEMPRESA","P_CDINSCESTA");
        parent::find($request,$response);
    }

    public function saveSubstitutoTributario(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $this->ger00250ParametrizacaoInscricaoEstadualService->salvarSubstitutoTributario($row);
        } catch (\Exception $e) {
            $response->setError(new Error("Error in data save. ". $e->getMessage(), 500));
        }
    }

    public function saveInscrestadst(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName='inscrestadst_completa';
        $this->dataSourceNameToSave='inscrestadst_completa';
        parent::save($request,$response);
    }

    public function saveCredprescfop(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName='credprescfop_telaInscricao';
        $this->dataSourceNameToSave='credprescfop';
        parent::save($request,$response);
    }

    public function deleteCredprescfop(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName='credprescfop_telaInscricao';
        parent::delete($request,$response);
    }

     public function deleteInscrestadst(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName='inscrestadst_completa';
        parent::delete($request,$response);
    }

    public function saveMensagem(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $this->ger00250ParametrizacaoInscricaoEstadualService->salvarMensagem($row);
        } catch (\Exception $e) {
            $response->setError(new Error("Error in data save. ". $e->getMessage(), 500));
        }
    }
    public function saveMensagemSubstituto(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $this->ger00250ParametrizacaoInscricaoEstadualService->salvarMensagemSubstituto($row);
        } catch (\Exception $e) {
            $response->setError(new Error("Error in data save. ". $e->getMessage(), 500));
        }
    }
    public function savediferencial(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $this->ger00250ParametrizacaoInscricaoEstadualService->salvardiferencial($row);
        } catch (\Exception $e) {
            $response->setError(new Error("Error in data save. ". $e->getMessage(), 500));
        }
    }

     public function saveDiferncialAliquota(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $row = $this->ger00250ParametrizacaoInscricaoEstadualService->preparRowDiferencialAliquota($row);
            $rows = $this->crudService->getRowsToSave($request, 'paramestsped');
            $this->ger00250ParametrizacaoInscricaoEstadualService->salvarDiferencialAliquota($rows);
        } catch (\Exception $e) {
            $response->setError(new Error("Error in data save. ". $e->getMessage(), 500));
        }
    }
    
    public function replicacaoAliqInt(DTO\Request $request, DTO\Response $response){
        try{
            
            $row  = $request->getRow();
            $result = $this->ger00250ParametrizacaoInscricaoEstadualService->replicacaoAliqInt($row, $response);
            
            $response->addDataSet(new DataSet('/result', [$result]));
            
        }catch(\Exception $e){
            $response->setError(new DTO\Response\Error($e->getMessage(), 500));
        }
    }
    
    public function cadastramentoAutomaticoAliqInt(DTO\Request $request, DTO\Response $response){
        try{
            
            $row  = $request->getRow();
            $result = $this->ger00250ParametrizacaoInscricaoEstadualService->cadastramentoAutomaticoAliqInt($row);
            
            $response->addDataSet(new DataSet('/result', [$result]));
            
        }catch(\Exception $e){
            $response->setError(new DTO\Response\Error($e->getMessage(), 500));
        }
    }
    
    public function saveAliquotaInt(DTO\Request $request, DTO\Response $response){
        try{
            
            $row  = $request->getRow();
            $result = $this->ger00250ParametrizacaoInscricaoEstadualService->saveAliquotaInt($row);
            
        }catch(\Exception $e){
            $response->setError(new DTO\Response\Error($e->getMessage(), 500));
        }
    }
    
    public function saveproduto(DTO\Request $request, DTO\Response $response){
        try{
            
            $row  = $request->getRow();
           
            $result = $this->ger00250ParametrizacaoInscricaoEstadualService->saveproduto($row);
            
        }catch(\Exception $e){
            $response->setError(new DTO\Response\Error($e->getMessage(), 500));
        }
    }
    
}