<?php
namespace Teknisa\CADFIS\Services;

use Zeedhi\Framework\DataSource\FilterCriteria;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\CADFIS\Factories\Ger00250ParametrizacaoInscricaoEstadualFactory;

class Ger00250ParametrizacaoInscricaoEstadualService{
    protected $environment;
    protected $dataSourceManager;
    protected $entityManager;
    protected $newCode;

    public function __construct(Environment $environment, \Doctrine\ORM\EntityManager $entityManager ,$dataSourceManager,NewCode $newCode, Ger00250ParametrizacaoInscricaoEstadualFactory $Ger00250ParametrizacaoInscricaoEstadualFactory){
        $this->environment = $environment;
        $this->entityManager = $entityManager;
        $this->dataSourceManager = $dataSourceManager;
        $this->newCode = $newCode;
        $this->Ger00250ParametrizacaoInscricaoEstadualFactory = $Ger00250ParametrizacaoInscricaoEstadualFactory;
        $this->nrorg = $this->environment->getNrOrgTrab();
    }

    public function buscar($condicao){
        return $this->dataSourceManager->findBy($condicao);
    }

    public function geraNovoCodigo($tableName, $nrorg, $interval, $colSize){
        return $this->newCode->getCodeByTableName($tableName, $nrorg, $interval, $colSize);
    }

    public function salvarSubstitutoTributario($row){
        try {
            $conditions = $this->condicaoSubstituto($row);
            $resultadoBanco = $this->realizaConsultaBanco($conditions,'inscrestadst');
            if($row['__is_new']){
                if(empty($resultadoBanco->getRows())){
                    $conditionsAdicionar = $this->condicaoSubstitutoAdicionar($row);
                    $resultado = $this->realizaConsultaBanco($conditionsAdicionar,'inscrestadst');
                    if(empty($resultado->getRows() ) ){
                        $operador = $this->environment->getCdOperador();
                        $nrorg = $this->environment->getNrorgTrab();
                        $currentTime = $this->environment->getCurrentTime()->format('d/m/Y');
                        $row->set('IDATIVO','S');
                        $row->set('NRORG',$nrorg);
                        $row->set('NRORGULTATU',$nrorg);
                        $row->set('DTINCLUSAO',$currentTime);
                        $row->set('DTULTATU',$currentTime);
                        $row->set('CDOPERINCLUSAO',$operador);
                        $row->set('CDOPERULTATU',$operador);
                        $row->set('NRORGINCLUSAO',$nrorg);
                        $array[] = $row;
                        $dataSet = new DataSet('inscrestadst_completa', $array);
                        $this->dataSourceManager->persist($dataSet);
                        $this->entityManager->flush();
                    }
                    else{
                        throw new \Exception('Código já cadastrado.');
                    }
                }
                else{
                    throw new \Exception('Inscrição Estadual já cadastrada para o estado informado.');
                }
            }
            else{
                if(empty($resultadoBanco->getRows())){
                    $array[] = $row;
                    $dataSet = new DataSet('inscrestadst_completa', $array);
                    $this->dataSourceManager->persist($dataSet);
                    $this->entityManager->flush();
                }
                else{
                    $resul = $resultadoBanco->getRows()[0];
                    if($resul['CDINSCESTAST']== $row['CDINSCESTAST']){
                        $array[] = $row;
                        $dataSet = new DataSet('inscrestadst_completa', $array);
                        $this->dataSourceManager->persist($dataSet);
                        $this->entityManager->flush();
                    }else{
                        throw new \Exception('Inscrição Estadual já cadastrada para o estado informado.');
                    }
                }
            }
        }catch (\Exception $e) {
            throw $e;
        }
    }

    public function preparRowDiferencialAliquota($row){
        try {
            $conditions  = $this->condicaoDiferencialAliquota($row);
            $resultadoBanco = $this->realizaConsultaBanco($conditions,'paramestsped');
            //verifica se ja existe registro
            if(empty( $resultadoBanco->getRows() )){
                $row->set('__is_new',true);
            }else{
                $row->set('__is_new',false);
            }
            return $row;
        }catch (\Exception $e) {
            throw $e;
        }
    }

    public function salvarDiferencialAliquota($row){
        try {
            $dataSet = new DataSet('paramestsped', $row);
            $this->dataSourceManager->persist($dataSet);
            $this->entityManager->flush();
        }catch (\Exception $e) {
            throw $e;
        }
    }

    public function salvarMensagem($row){
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();

            if($row['__is_new']){
                $conditions = $this->condicaoMensagem($row);
                $resultadoBanco = $this->realizaConsultaBanco($conditions,'mensinscrestad');
                if(empty($resultadoBanco->getRows())){
                    $operador = $this->environment->getCdOperador();
                    $nrorg = $this->environment->getNrorgTrab();
                    $currentTime = $this->environment->getCurrentTime()->format('d/m/Y');
                    $novoCodigoMensagem = $this->geraNovoCodigo('MENSINSCRESTAD',$this->environment->getNrOrgTrab(), 1, 5);
                    $row->set('IDATIVO','S');
                    $row->set('NRORG',$nrorg);
                    $row->set('NRORGULTATU',$nrorg);
                    $row->set('DTINCLUSAO',$currentTime);
                    $row->set('DTULTATU',$currentTime);
                    $row->set('CDOPERINCLUSAO',$operador);
                    $row->set('CDOPERULTATU',$operador);
                    $row->set('NRORGINCLUSAO',$nrorg);
                    $row->set('NRMENSINSCRESTA',$novoCodigoMensagem);
                    $array[] = $row;
                    $dataSet = new DataSet('mensinscrestad', $array);
                    $this->dataSourceManager->persist($dataSet);
                    $this->entityManager->flush();
                }
                else{
                    throw new \Exception('Impossível Adicionar. Registro já existe.');
                }
            } else {
                $sql = "UPDATE MENSINSCRESTAD
                            SET IDENTRSAIDMENS = :IDENTRSAIDMENS
                            WHERE NRMENSINSCRESTA = :NRMENSINSCRESTA
                            AND CDINSCESTA = :CDINSCESTA
                            AND CDEMPRESA = :CDEMPRESA";
                $params =
                    array(
                        'IDENTRSAIDMENS'  => $row['IDENTRSAIDMENS'],
                        'NRMENSINSCRESTA' => $row['NRMENSINSCRESTA'],
                        'CDINSCESTA'      => $row['CDINSCESTA'],
                        'CDEMPRESA'       => $row['CDEMPRESA']
                );
                $query = $this->entityManager->getConnection()->prepare($sql);
                $query->execute($params);
            }
            $connection->commit();
        }catch (\Exception $e) {
            throw $e;
        }

    }

    public function salvarMensagemSubstituto($row){
        try {
            if($row['__is_new']){
                $conditions = $this->condicaoMensagemSubstituto($row);
                $resultadoBanco = $this->realizaConsultaBanco($conditions,'mensinscestast');
                if(empty($resultadoBanco->getRows())){
                    $operador = $this->environment->getCdOperador();
                    $nrorg = $this->environment->getNrorgTrab();
                    $currentTime = $this->environment->getCurrentTime()->format('d/m/Y');
                    $novoCodigoMensagem = $this->geraNovoCodigo('MENSINSCESTAST',$this->environment->getNrOrgTrab(), 1, 5);
                    $row->set('IDATIVO','S');
                    $row->set('NRORG',$nrorg);
                    $row->set('NRORGULTATU',$nrorg);
                    $row->set('DTINCLUSAO',$currentTime);
                    $row->set('DTULTATU',$currentTime);
                    $row->set('CDOPERINCLUSAO',$operador);
                    $row->set('CDOPERULTATU',$operador);
                    $row->set('NRORGINCLUSAO',$nrorg);
                    $row->set('NRMENSINSCESTAST',$novoCodigoMensagem);

                    $array[] = $row;
                    $dataSet = new DataSet('mensinscestast', $array);
                    $this->dataSourceManager->persist($dataSet);
                    $this->entityManager->flush();
                }
                else{
                    throw new \Exception('Impossível Adicionar. Registro já existe.');
                }
            }else{
                $array[] = $row;
                $dataSet = new DataSet('mensinscestast', $array);
                $this->dataSourceManager->persist($dataSet);
                $this->entityManager->flush();
            }
        }catch (\Exception $e) {
            throw $e;
        }
    }

    public function condicaoDiferencialAliquota($row) {
        $conditions = array(
            array(
                "value" => $this->environment->getNrOrgTrab(),
                "operator" => "=",
                "columnName" => "NRORG"
            ),
            array(
                "value" => $row['CDEMPRESA'],
                "operator" => "=",
                "columnName" => "CDEMPRESA"
            ),
            array(
                "value" => $row['CDINSCESTA'],
                "operator" => "=",
                "columnName" => "CDINSCESTA"
            ),
            array(
                "value" => $row['IDDIFEALIQUOTA'],
                "operator" => "=",
                "columnName" => "IDDIFEALIQUOTA"
            ),
            array(
                "value" => $row['CDAJUSTE'],
                "operator" => "=",
                "columnName" => "CDAJUSTE"
            ),
            array(
                "value" => $row['DSAJUSTE'],
                "operator" => "=",
                "columnName" => "DSAJUSTE"
            ),
            array(
                "value" => $row['CDAJUSTENFEXTEMP'],
                "operator" => "=",
                "columnName" => "CDAJUSTENFEXTEMP"
            ),
            array(
                "value" => $row['DSAJUSTENFEXTEMP'],
                "operator" => "=",
                "columnName" => "DSAJUSTENFEXTEMP"
            )

        );
        return $conditions;
    }

    public function condicaoSubstituto($row) {
        $conditions = array(
            array(
                "value" => $this->environment->getNrOrgTrab(),
                "operator" => "=",
                "columnName" => "NRORG"
            ),
            array(
                "value" => $row['SGESTADO'],
                "operator" => "=",
                "columnName" => "SGESTADO"
            ),
            array(
                "value" => $row['CDEMPRESA'],
                "operator" => "=",
                "columnName" => "CDEMPRESA"
            ),
            array(
                "value" => $row['CDPAIS'],
                "operator" => "=",
                "columnName" => "CDPAIS"
            ),
            array(
                "value" => $row['CDINSCESTA'],
                "operator" => "=",
                "columnName" => "CDINSCESTA"
            )
        );
        return $conditions;
    }

    public function condicaoSubstitutoAdicionar($row) {
        $conditions = array(
            array(
                "value" => $this->environment->getNrOrgTrab(),
                "operator" => "=",
                "columnName" => "NRORG"
            ),
            array(
                "value" => $row['CDINSCESTAST'],
                "operator" => "=",
                "columnName" => "CDINSCESTAST"
            ),
            array(
                "value" => $row['CDEMPRESA'],
                "operator" => "=",
                "columnName" => "CDEMPRESA"
            ),
            array(
                "value" => $row['CDINSCESTA'],
                "operator" => "=",
                "columnName" => "CDINSCESTA"
            )
        );
        return $conditions;
    }

    public function condicaoMensagem($row) {
        $conditions = array(
            array(
                "value" => $this->environment->getNrOrgTrab(),
                "operator" => "=",
                "columnName" => "NRORG"
            ),
            array(
                "value" => $row['CDMENSAGEM'],
                "operator" => "=",
                "columnName" => "CDMENSAGEM"
            ),
            array(
                "value" => $row['CDEMPRESA'],
                "operator" => "=",
                "columnName" => "CDEMPRESA"
            ),
            array(
                "value" => $row['CDINSCESTA'],
                "operator" => "=",
                "columnName" => "CDINSCESTA"
            )
        );
        return $conditions;
    }

    public function condicaoMensagemSubstituto($row) {
        $conditions = array(
            array(
                "value" => $this->environment->getNrOrgTrab(),
                "operator" => "=",
                "columnName" => "NRORG"
            ),
            array(
                "value" => $row['CDMENSAGEM'],
                "operator" => "=",
                "columnName" => "CDMENSAGEM"
            ),
            array(
                "value" => $row['CDEMPRESA'],
                "operator" => "=",
                "columnName" => "CDEMPRESA"
            ),
            array(
                "value" => $row['CDINSCESTA'],
                "operator" => "=",
                "columnName" => "CDINSCESTA"
            ),
            array(
                "value" => $row['CDINSCESTAST'],
                "operator" => "=",
                "columnName" => "CDINSCESTAST"
            )
        );
        return $conditions;
  }

    public function realizaConsultaBanco($conditions,$dataSourceName) {
        $filterCriteria = new FilterCriteria($dataSourceName,$conditions);
        $dataSet = $this->buscar($filterCriteria);
        return $dataSet;
    }

    public function replicacaoAliqInt($row, $response){
        try{
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();

            $row['NRORG'] = $this->nrorg;
            $selectPROD = $this->Ger00250ParametrizacaoInscricaoEstadualFactory->selectALIQINTPRODIE($row['CDEMPRESA_ORIG'], $row['CDINSCESTA_ORIG'], $row['NRORG']);

            if ($selectPROD){
                foreach ($selectPROD as $orig){
                    $existeDest = $this->Ger00250ParametrizacaoInscricaoEstadualFactory->selectALIQINTPRODIE_PROD($row['CDEMPRESA_DEST'], $row['CDINSCESTA_DEST'], $orig['CDPRODUTO'], $row['NRORG']);
                    if($existeDest){
                        $this->Ger00250ParametrizacaoInscricaoEstadualFactory->updateALIQINTPRODIE($row['CDEMPRESA_DEST'], $row['CDINSCESTA_DEST'], $orig['CDPRODUTO'], $orig['VRALIQINT'], $orig['VRALIQFECP'], $row['NRORG']);
                    } else {
                        $orig['NRSEQALIQINT'] = $this->Ger00250ParametrizacaoInscricaoEstadualFactory->getMaxNRSEQALIQINT()['NRSEQALIQINT'] + 1;

                        $this->Ger00250ParametrizacaoInscricaoEstadualFactory->insertALIQINTPRODIE($orig['NRSEQALIQINT'], $row['CDEMPRESA_DEST'], $row['CDINSCESTA_DEST'], $orig['CDPRODUTO'], $orig['VRALIQINT'], $orig['VRALIQFECP'], $row['NRORG'], $row['DTATUAL'], $row['CDOPERADOR']);
                    }
                }

                $connection->commit();
                return true;
            } else {
                $array = [
                    "EMPRESA"=>$row['CDEMPRESA_ORIG'],
                    "INSCESTA"=>$row['CDINSCESTA_ORIG']
                ];
                throw (new \Exception('Empresa sem parametros: '.json_encode($array), 500));
            }
        }catch(\Exception $e){
            $this->entityManager->rollback();
            throw $e;
        }
    }

    public function cadastramentoAutomaticoAliqInt($row){
        try{
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();

            $row['NRORG'] = $this->nrorg;
            $selectProd = $this->Ger00250ParametrizacaoInscricaoEstadualFactory->selectProdCadastAutom($row);

            if ($selectProd){
                foreach ($selectProd as $produto){
                    $existeVRMAXVENPROD = $this->Ger00250ParametrizacaoInscricaoEstadualFactory->selectALIQINTPRODIE_PROD($row['CDEMPRESA'], $row['CDINSCESTA'], $produto['CDPRODUTO'], $row['NRORG']);
                    if($existeVRMAXVENPROD){
                        $this->Ger00250ParametrizacaoInscricaoEstadualFactory->updateALIQINTPRODIE($row['CDEMPRESA'], $row['CDINSCESTA'], $produto['CDPRODUTO'], $row['VRALIQINT'], $row['VRALIQFECP'], $row['NRORG']);
                    } else {
                        $produto['NRSEQALIQINT'] = $this->Ger00250ParametrizacaoInscricaoEstadualFactory->getMaxNRSEQALIQINT()['NRSEQALIQINT'] + 1;

                        $this->Ger00250ParametrizacaoInscricaoEstadualFactory->insertALIQINTPRODIE($produto['NRSEQALIQINT'], $row['CDEMPRESA'], $row['CDINSCESTA'], $produto['CDPRODUTO'], $row['VRALIQINT'], $row['VRALIQFECP'], $row['NRORG'], $row['DTATUAL'], $row['CDOPERADOR']);
                    }
                }

                $connection->commit();
                return true;
            } else {
               throw new \Exception('Ocorreu um erro ao realizar o cadastro automatico.');
            }
        }catch(\Exception $e){
            $this->entityManager->rollback();
            throw $e;
        }
    }

    public function saveAliquotaInt($row) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();

            $row['NRSEQALIQINT'] = $this->Ger00250ParametrizacaoInscricaoEstadualFactory->getMaxNRSEQALIQINT()['NRSEQALIQINT'] + 1;

            $this->Ger00250ParametrizacaoInscricaoEstadualFactory->insertALIQINTPRODIE($row['NRSEQALIQINT'], $row['CDEMPRESA'], $row['CDINSCESTA'], $row['CDPRODUTO'], $row['VRALIQINT'], $row['VRALIQFECP'], $this->nrorg, $row['DTATUAL'], $row['CDOPERADOR']);

            $connection->commit();
            return true;

        } catch(\Exception $e) {
            $this->entityManager->rollback();
            throw $e;
        }
    }
    
     public function saveproduto($row) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();

            $cdproduto = $this->Ger00250ParametrizacaoInscricaoEstadualFactory->getproduto($row);
            $row['CDPRODUTO'] = $cdproduto[0]['CDPRODUTO'];
            $row['NRORG'] = $this->nrorg;
          //  var_dump($row);die;
            $array[] = $row;
                    $dataSet = new DataSet('credpresproduto_PorProduto', $array);
                    $this->dataSourceManager->persist($dataSet);
                    $this->entityManager->flush();
            

        } catch(\Exception $e) {
            $this->entityManager->rollback();
            throw $e;
        }
    }

}