<?php
namespace Teknisa\CADFIS\Services;

use Zeedhi\Framework\DataSource\FilterCriteria;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\CADFIS\Factories\Ger01500MunicipioFactory;

class Ger01500MunicipioService{
    protected $dataSourceManager;
    protected $ger01500municipiofactory;
    protected $environment;

    public function __construct($dataSourceManager, $ger01500municipiofactory, Environment $environment, $fileServerUrl){
        $this->dataSourceManager = $dataSourceManager;
        $this->ger01500municipiofactory = $ger01500municipiofactory;
        $this->environment = $environment;
        $this->fileServerUrl = $fileServerUrl;
    }

    public function saveMunicipio($row){
        if($row['__is_new']){
            $this->verficaCodigoMunicipio($row);
        }
        $this->verficaNomeMunicipio($row);
        $this->verficaIBGEMunicipio($row);
        $array[] = $row;
        $dataSet = new DataSet('municipio', $array);
        $this->dataSourceManager->persist($dataSet);
    }

    //não permite salvar estado com mesmo nome para um mesmo pais
    public function verficaNomeMunicipio($row){
        $resultadoBanco = $this->ger01500municipiofactory->verficaNomeMunicipio($row);
        if(!empty ($resultadoBanco) ){
            // no caso de edição para verificar se o ESTADO ja existe na base e está sendo editado
            if($resultadoBanco[0]['CDMUNICIPIO']  !== $row['CDMUNICIPIO']){
                throw new \Exception("Nome já cadastrado.", 1);

            }
        }
    }
    
    //não permite salvar IBGE com mesmo nome para um mesmo pais
    public function verficaIBGEMunicipio($row){
        
        $resultadoBanco = $this->ger01500municipiofactory->verficaIBGEMunicipio($row);
        
        if(!empty ($resultadoBanco) ){
            
            // no caso de edição para verificar se o ESTADO ja existe na base e está sendo editado
            if($resultadoBanco[0]['CDMUNICIBGE']  == $row['CDMUNICIBGE']){
                throw new \Exception("Código IBGE já cadastrado já cadastrado.", 1);

            }
        }
    }
    
    public function verficaCodigoMunicipio($row){
        $resultadoBanco = $this->ger01500municipiofactory->verficaCodigoMunicipio($row);
        if(!empty($resultadoBanco)){
            throw new \Exception("Código já cadastrado.", 1);
        }
    }
    
    public function novoCodigoBairro($row){
        return  $this->ger01500municipiofactory->novoCodigoBairro($row['CDPAIS'], $row['SGESTADO'], $row['CDMUNICIPIO']);
    }
    
    public function novoCodigoRegiao($row){
        return  $this->ger01500municipiofactory->novoCodigoRegiao($row['CDPAIS'], $row['SGESTADO'], $row['CDMUNICIPIO']);
        
    }
    
    public function saveLogomarca($row){
    
        $params = $this->setParamsLogomarca($row);
        $this->ger01500municipiofactory->saveLogomarca($params);
    }
    
    public function setDataSetLogomarca($response){
        $rows = $response->getDataSets()[0]->getRows();
        if( sizeof( $rows ) > 0 ){
            if( sizeof($rows[0]['DSDIRLOGOMARCA']) ){
                $rowAntiga = (array)$rows[0];
                $dsdir = explode(">", $rowAntiga['DSDIRLOGOMARCA']);
                $name = substr($dsdir[0], 1);
                $link = $this->fileServerUrl.$dsdir[1];
                $dataSet = new DataSet('logomarca_municipio', 
                    array( 
                        array(
                            "DSDIRLOGOMARCA" => $link,
                            "NMARQUIVO" => $name
                        )
                    )
                );
                $response->setDataSets(array($dataSet));
            }else{
                $dataSet = new DataSet('logomarca_municipio', array() );
                $response->setDataSets(array($dataSet));
            } 
        }
        
        
    }
    
    public function setParamsLogomarca($row){
        $params = array(
            "P_CDMUNICIPIO"    => $row["CDMUNICIPIO"],
            "P_DSDIRLOGOMARCA" => $row["__is_new"] ? '<'.$row["LOGOMARCA"][0]["name"].'>'.$row["LOGOMARCA"][0]["path"] : null
        );
        return $params;
    }
    
}