<?php
namespace Teknisa\CADFIS\Strategies;

use Teknisa\Libs\Util\Environment;
use Teknisa\CADFIS\Strategies\GeneralStrategy;
use Teknisa\CADFIS\Services\RegiaoService as RegiaoService;

class RegiaoStrategy extends GeneralStrategy implements Interfaces\IStrategy
{
    protected $service;

    public function __construct(RegiaoService $service, Environment $environment)
    {
		$this->service = $service;
		$this->environment = $environment;
	}
	
	public function validate(&$data)
    {
        //parent::verifyIsEmpty($data);
        
        foreach ($data as &$row) {
            parent::verifyIsEmpty($row, $row["ROWNUM"], ['CDREGIAO', 'NMREGIAO', 'CDPAIS', 'SGESTADO']);
            parent::verifyCdRegiao($row, $row["ROWNUM"]);
            self::verifyCdRegiaoExists($row, $row["ROWNUM"]);
            parent::verifyCdPais($row, $row["ROWNUM"]);
            self::verifyCdPaisExists($row, $row["ROWNUM"]);
            parent::verifySgEstado($row, $row["ROWNUM"]);
            self::verifySgEstadoExists($row, $row["ROWNUM"]);
            
            $row['ERROS'] = $this->errors;
            
            parent::clearErrors();
        }
    }
    
    private function verifyCdRegiaoExists($row, $rowNum)
    {
        if ($this->service->verifyCdRegiaoExists($row)) {
            parent::setError($rowNum, 'CDREGIAO', $row['CDREGIAO'], "ALREADY_REGISTERED");
        }
    }
    
    private function verifyCdPaisExists($row, $rowNum)
    {
        if (!$this->service->verifyCdPaisExists($row)) {
            parent::setError($rowNum, 'CDPAIS', $row['CDPAIS'], "UNREGISTERED");
        }
    }
    
    private function verifySgEstadoExists($row, $rowNum)
    {
        if (!$this->service->verifySgEstadoExists($row)) {
            parent::setError($rowNum, 'SGESTADO', $row['SGESTADO'], "UNREGISTERED");
        }
    }
    
    public function formatToView(&$data)
    {
        foreach ($data as &$row) {
           $row['CDREGIAO'] = parent::formatColumn($row['CDREGIAO'], 3);
           $row['IDERROR'] = !empty($row['ERROS']) ? 'S' : 'N';
        }
    }
    
    public function save($data)
    {
        self::validate($data);
        parent::verifyExistErros($data);
        $this->service->saveImport($data);
    }
}